@@ -23,7 +23,7 @@ from aliyunsdkiot.endpoint import endpoint_data
 class PubRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'Pub')
+		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'Pub','iot')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -65,6 +65,12 @@ class PubRequest(RpcRequest):
 	def set_IotInstanceId(self,IotInstanceId):
 		self.add_query_param('IotInstanceId',IotInstanceId)
 
+	def get_MessageExpiryInterval(self):
+		return self.get_query_params().get('MessageExpiryInterval')
+
+	def set_MessageExpiryInterval(self,MessageExpiryInterval):
+		self.add_query_param('MessageExpiryInterval',MessageExpiryInterval)
+
 	def get_ResponseTopic(self):
 		return self.get_query_params().get('ResponseTopic')
 
@@ -77,12 +83,30 @@ class PubRequest(RpcRequest):
 	def set_TopicFullName(self,TopicFullName):
 		self.add_query_param('TopicFullName',TopicFullName)
 
+	def get_PayloadFormatIndicator(self):
+		return self.get_query_params().get('PayloadFormatIndicator')
+
+	def set_PayloadFormatIndicator(self,PayloadFormatIndicator):
+		self.add_query_param('PayloadFormatIndicator',PayloadFormatIndicator)
+
 	def get_ProductKey(self):
 		return self.get_query_params().get('ProductKey')
 
 	def set_ProductKey(self,ProductKey):
 		self.add_query_param('ProductKey',ProductKey)
 
+	def get_ContentType(self):
+		return self.get_query_params().get('ContentType')
+
+	def set_ContentType(self,ContentType):
+		self.add_query_param('ContentType',ContentType)
+
+	def get_Retained(self):
+		return self.get_query_params().get('Retained')
+
+	def set_Retained(self,Retained):
+		self.add_query_param('Retained',Retained)
+
 	def get_DeviceName(self):
 		return self.get_query_params().get('DeviceName')
 
