@@ -23,7 +23,7 @@ from aliyunsdkiot.endpoint import endpoint_data
 class RRpcRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'RRpc')
+		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'RRpc','iot')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -55,6 +55,12 @@ class RRpcRequest(RpcRequest):
 	def set_ProductKey(self,ProductKey):
 		self.add_query_param('ProductKey',ProductKey)
 
+	def get_ContentType(self):
+		return self.get_query_params().get('ContentType')
+
+	def set_ContentType(self,ContentType):
+		self.add_query_param('ContentType',ContentType)
+
 	def get_Topic(self):
 		return self.get_query_params().get('Topic')
 
